StreamDispatchStats

Struct StreamDispatchStats 

pub struct StreamDispatchStats {
    pub delivered: u64,
    pub dropped_full: u64,
    pub dropped_closed: u64,
}
Snapshot of stream dispatch behavior for one stream key.

Fields

delivered: u64

Number of events successfully queued to the stream channel.

dropped_full: u64

Number of events dropped because the channel was full.

dropped_closed: u64

Number of events dropped because the channel was closed.