pub struct StreamDispatchStats {
pub delivered: u64,
pub dropped_full: u64,
pub dropped_closed: u64,
}Expand description
Snapshot of stream dispatch behavior for one stream key.
Fields
delivered: u64Number of events successfully queued to the stream channel.
dropped_full: u64Number of events dropped because the channel was full.
dropped_closed: u64Number of events dropped because the channel was closed.